Fix naming inconsistency.
diff --git a/Include/longobject.h b/Include/longobject.h
index 72bcd98..02bf7ef 100644
--- a/Include/longobject.h
+++ b/Include/longobject.h
@@ -101,13 +101,13 @@
 */
 PyAPI_FUNC(size_t) _PyLong_NumBits(PyObject *v);
 
 /* _PyLong_Divmod_Near.  Given integers a and b, compute the nearest
    integer q to the exact quotient a / b, rounding to the nearest even integer
    in the case of a tie.  Return (q, r), where r = a - q*b.  The remainder r
    will satisfy abs(r) <= abs(b)/2, with equality possible only if q is
    even.
 */
-PyAPI_FUNC(PyObject *) _PyLong_Divmod_Near(PyObject *, PyObject *);
+PyAPI_FUNC(PyObject *) _PyLong_DivmodNear(PyObject *, PyObject *);
 
 /* _PyLong_FromByteArray:  View the n unsigned bytes as a binary integer in
    base 256, and return a Python long with the same numeric value.
@@ -101,13 +101,13 @@
 PyAPI_FUNC(size_t) _PyLong_NumBits(PyObject *v);
 
-/* _PyLong_Divmod_Near.  Given integers a and b, compute the nearest
+/* _PyLong_DivmodNear.  Given integers a and b, compute the nearest
    integer q to the exact quotient a / b, rounding to the nearest even integer
    in the case of a tie.  Return (q, r), where r = a - q*b.  The remainder r